[−][src]Module nom_unicode::streaming
Nom streaming parsing API functions.
Functions
| alpha0 | Recognizes zero or more lowercase and uppercase alphabetic Unicode characters. |
| alpha1 | Recognizes one or more lowercase and uppercase alphabetic Unicode characters. |
| alphanumeric0 | Recognizes zero or more alphabetic and numeric Unicode characters. |
| alphanumeric1 | Recognizes one or more alphabetic and numeric Unicode characters. |
| ascii0 | Recognizes zero or more ASCII characters. |
| ascii1 | Recognizes one or more ASCII characters. |
| control0 | Recognizes zero or more control Unicode characters. |
| control1 | Recognizes one or more control Unicode characters. |
| digit0 | Recognizes zero or more numeric Unicode characters. |
| digit1 | Recognizes one or more numeric Unicode characters. |
| lower0 | Recognizes zero or more lowercase alphabetic Unicode characters. |
| lower1 | Recognizes one or more lowercase alphabetic Unicode characters. |
| space0 | Recognizes zero or more whitespace Unicode characters. |
| space1 | Recognizes one or more whitespace Unicode characters. |
| upper0 | Recognizes zero or more lowercase alphabetic Unicode characters. |
| upper1 | Recognizes one or more lowercase alphabetic Unicode characters. |